[llvm-commits] CVS: llvm/include/llvm/CodeGen/MachineModuleInfo.h

Anton Korobeynikov asl at math.spbu.ru
Thu May 10 15:35:23 PDT 2007



Changes in directory llvm/include/llvm/CodeGen:

MachineModuleInfo.h updated: 1.11 -> 1.12
---
Log message:

Allow multiple invokes per landing pad. This (probably) fixes PR1410: http://llvm.org/PR1410 .


---
Diffs of the changes:  (+3 -4)

 MachineModuleInfo.h |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)


Index: llvm/include/llvm/CodeGen/MachineModuleInfo.h
diff -u llvm/include/llvm/CodeGen/MachineModuleInfo.h:1.11 llvm/include/llvm/CodeGen/MachineModuleInfo.h:1.12
--- llvm/include/llvm/CodeGen/MachineModuleInfo.h:1.11	Sun May  6 08:37:16 2007
+++ llvm/include/llvm/CodeGen/MachineModuleInfo.h	Thu May 10 17:34:59 2007
@@ -33,6 +33,7 @@
 
 #include "llvm/Support/Dwarf.h"
 #include "llvm/Support/DataTypes.h"
+#include "llvm/ADT/SmallVector.h"
 #include "llvm/ADT/UniqueVector.h"
 #include "llvm/GlobalValue.h"
 #include "llvm/Pass.h"
@@ -955,8 +956,8 @@
 ///
 struct LandingPadInfo {
   MachineBasicBlock *LandingPadBlock;   // Landing pad block.
-  unsigned BeginLabel;                  // Label prior to invoke.
-  unsigned EndLabel;                    // Label after invoke.
+  SmallVector<unsigned, 1> BeginLabels; // Labels prior to invoke.
+  SmallVector<unsigned, 1> EndLabels;   // Labels after invoke.
   unsigned LandingPadLabel;             // Label at beginning of landing pad.
   Function *Personality;                // Personality function.
   std::vector<unsigned> TypeIds;        // List of type ids.
@@ -965,8 +966,6 @@
   
   LandingPadInfo(MachineBasicBlock *MBB)
   : LandingPadBlock(MBB)
-  , BeginLabel(0)
-  , EndLabel(0)
   , LandingPadLabel(0)
   , TypeIds()
   , IsFilter(false)






More information about the llvm-commits mailing list